__version__ = "0.1.9"

from .const import HORIZONTAL, VERTICAL, H, Orient, V
from .event import SkEvent
from .styles import *  # 基础样式，包括颜色等
from .var import SkBooleanVar, SkEventHandling, SkFloatVar, SkIntVar, SkStringVar, SkVar
from .widgets import *
